@@ -10,7 +10,12 @@ import time
 from uuid import uuid1
 from urllib.parse import urljoin
 
-
+try:
+    import pkg_resources
+    version = 'v' + pkg_resources.get_distribution("kucoin-futures-python").version
+except (ModuleNotFoundError, pkg_resources.DistributionNotFound):
+    version = 'v1.0.0'
+    
 class KucoinFuturesBaseRestApi(object):
 
     def __init__(self, key='', secret='', passphrase='', is_sandbox=False, url='', is_v1api=False):
@@ -40,7 +45,6 @@ class KucoinFuturesBaseRestApi(object):
     def _request(self, method, uri, timeout=5, auth=True, params=None):
         uri_path = uri
         data_json = ''
-        version = 'v1.0.3'
         if method in ['GET', 'DELETE']:
             if params:
                 strl = []
