@@ -1,4 +1,6 @@
 from kucoin_futures.websocket.websocket import ConnectWebsocket
+import asyncio
+
 
 class KucoinFuturesWsClient(object):
     """
@@ -11,10 +13,12 @@ class KucoinFuturesWsClient(object):
         self._loop = None
         self._client = None
         self._private = False
+        self._topics = set()
 
     @classmethod
     async def create(cls, loop, client, callback, private=False):
         self = KucoinFuturesWsClient()
+        loop = loop if loop else asyncio.get_running_loop()
         self._loop = loop
         self._client = client
         self._private = private
@@ -38,7 +42,7 @@ class KucoinFuturesWsClient(object):
             'topic': topic,
             'response': True
         }
-
+        self._conn.topics.append(topic)
         await self._conn.send_message(req_msg)
 
     async def unsubscribe(self, topic):
@@ -54,5 +58,5 @@ class KucoinFuturesWsClient(object):
             'topic': topic,
             'response': True
         }
-
+        self._conn.topics.remove(topic)
         await self._conn.send_message(req_msg)
